#
# spec file for package python-tri.declarative
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-tri.declarative
Version:        5.7.0
Release:        1.12
Summary:        Python class decorators in the style of Django model classes
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/TriOptima/tri.declarative
Source:         https://github.com/TriOptima/tri.declarative/archive/%{version}.tar.gz#/tri.declarative-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module pytest >= 4.0}
BuildRequires:  %{python_module tri.struct >= 3.0.0}
# /SECTION
BuildRequires:  fdupes
Requires:       python-tri.struct >= 3.0.0
BuildArch:      noarch

%python_subpackages

%description
tri.declarative contains class decorators to define classes with
subclass semantics in the style of django Model classes.

%prep
%setup -q -n tri.declarative-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc AUTHORS.rst README.rst
%license LICENSE
%{python_sitelib}/tri_declarative
%{python_sitelib}/tri.declarative-%{version}*-info

%changelog
* Fri Jan 22 2021 Benjamin Greiner <code@bnavigator.de>
- Update to 5.7.0
  * Make getattr_path more in line with the standard library
    getattr semantics
  * If a default value is provided, return that on missing
    attributes
  * If no default value is given, give a more detailed
    error message of what was missing
  * Added the special case of the empty path returning the object
- Changes in 5.6.0
  * Fix corner case of class Meta failing to merge with
    None namespace values
- Changes in 5.5.0
  * Include tri.struct 4.x as possible requirement
* Thu Jul 23 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 5.4.1
  * Minor bug fix on trailing comma explanation TypeException
  * Fix bug when nesting `@class_shortcut` with same name i sub classes
  * Refactor code to separate modules to get better stack traces
* Fri May 29 2020 Tomáš Chvátal <tchvatal@suse.com>
- Switch to pytest5 and disable one test that does not work with it
* Fri Apr 17 2020 pgajdos@suse.com
- version update to 5.3.0
  * Enable `@class_shortcut` to override baseclass shortcuts with the same name.
  * Fix `@with_meta` failing on method declarations with `@staticmethod` declaration
* Wed Mar 11 2020 pgajdos@suse.com
- version update to 5.2.0
  5.2.0 (2020-02-28)
  - -----------------
  * The namespace merge is narrowed to only affect the @with_meta case.
  * Handle calling `Namespace` with `call_target__attribute=None`
  5.1.1 (2020-02-11)
  - -----------------
  * Improve namespace merge in @with_meta to not trip up @declarative
  5.1.0 (2020-02-11)
  - -----------------
  * Fix @with_meta argument injector to merge namespaces
  5.0.1 (2019-02-03)
  - -----------------
  * A minor update to the documentation generation to make it play nice with rST
  5.0.0 (2019-01-30)
  - -----------------
  * Added private field to shortcuts: `__tri_declarative_shortcut_stack`. This is useful to be able to figure out a shortcut stack after the fact
  * `get_callable_description` thought stuff that contained a lambda in its string representation was a lambda
  * Removed all deprecated APIs/behaviors:
  * `creation_ordered`
  * The promotion of string values to keys in `Namespace`
  * Much improved error messages
  4.0.1 (2019-10-23)
  - -----------------
  * Bugfix to correctly handle Namespace as callable/not callable depending on content
  4.0.0 (2019-10-11)
  - -----------------
  * `get_meta()` now collects extra arguments in a `Namespace` to get consistent override behaviour.
  * `should_show` no longer accepts a callable as a valid return value. It will assert on this, because it's always a mistake.
  * Added `evaluate_strict` and `evaluate_recursive_strict` that will not accept callables left over after the evaluation. If possible prefer these methods because they will stop the user of your library from making the mistake of not matching the given signature and ending up with an unevaluated callable in the output.
* Thu Aug  8 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v3.1.0
